#!/usr/bin/env python3
from stepup.reprep.api import compile_latex, getenv, render_jinja

PUBLIC = getenv("PUBLIC", back=True)
render_jinja("main.tex", ["../variables.py", "variables.py"], PUBLIC)
compile_latex("main.tex", workdir=PUBLIC)



#!/usr/bin/env python3

from stepup.core.api import static
from stepup.reprep.api import compile_latex

static("paper.tex")
static("bibsane.yaml")
static("references.bib")
compile_latex("${LATEX_MAIN}.tex")



#!/usr/bin/env python3
from stepup.core.api import static
from stepup.reprep.api import render_jinja

static("template.md", "variables.py")
render_jinja("template.md", ["variables.py"], "rendered.md")



#!/usr/bin/env python3
from stepup.core.api import static, step
from stepup.reprep.api import compile_typst

static("image.py", "document.typ")
compile_typst("document.typ")
step("./image.py", out="image.jpg")
